//
// Copyright (c) 2012 Samsung Electronics Co., Ltd.
//
// Licensed under the Flora License, Version 1.1 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://floralicense.org/license/
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an AS IS BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

#include <FBase.h>
#include <FApp.h>
#include <FSystem.h>
#include <FUiAnimControlAnimator.h>
#include <FUiAnimRotateAnimation.h>

#include "GalleryAppWidgetProvider.h"
#include "GalleryAppWidgetPopupProvider.h"

using namespace Tizen::App;
using namespace Tizen::Base;
using namespace Tizen::Graphics;
using namespace Tizen::System;
using namespace Tizen::Ui;
using namespace Tizen::Ui::Controls;
using namespace Tizen::Shell;
using namespace Tizen::Base::Runtime;
using namespace Tizen::Ui::Animations;

GalleryAppWidgetPopupProvider::GalleryAppWidgetPopupProvider()
{

}

GalleryAppWidgetPopupProvider::~GalleryAppWidgetPopupProvider()
{

}

bool
GalleryAppWidgetPopupProvider::OnAppWidgetPopupProviderInitializing(const Tizen::Base::String& userInfo)
{
	AppLog("userInfo: %ls", userInfo.GetPointer() );

	float width = 720.0f;
	float height = 250.0f;

	Tizen::Shell::AppWidgetPopup* pAppWidgetPopup = new AppWidgetPopup;
	TryReturn(pAppWidgetPopup, false, "Failed to allocate memory for pAppWidgetPopup.");

	RelativeLayout relativeLayout;// = new RelativeLayout();
	relativeLayout.Construct();
	pAppWidgetPopup->Construct(relativeLayout, FloatDimension(width, height));

	// Create a Button
	Button* pButton1 = new Button();
	pButton1->Construct(Rectangle(20, 50, 300, 100));
	pButton1->SetText(L"Prev");
	pButton1->SetActionId(ID_BUTTON_PREV);
	pButton1->AddActionEventListener(*this);

	pAppWidgetPopup->AddControl(pButton1);

	Button* pButton2 = new Button();
	pButton2->Construct(Rectangle(400, 50, 300, 100));
	pButton2->SetText(L"Next");
	pButton2->SetActionId(ID_BUTTON_NEXT);
	pButton2->AddActionEventListener(*this);

	pAppWidgetPopup->AddControl(pButton2);

	relativeLayout.SetRelation(*pButton1, pAppWidgetPopup, RECT_EDGE_RELATION_LEFT_TO_LEFT);
	relativeLayout.SetMargin(*pButton1, 28, 0, 0, 0);
	relativeLayout.SetRelation(*pButton2, pAppWidgetPopup, RECT_EDGE_RELATION_RIGHT_TO_RIGHT);
	relativeLayout.SetMargin(*pButton2, 0, 28, 0, 0);

	SetAppWidgetPopup(pAppWidgetPopup);

	pAppWidgetPopup->Show();

	return true;
}

void
GalleryAppWidgetPopupProvider::OnAppWidgetPopupProviderTerminating()
{
	AppLog("");
}

void
GalleryAppWidgetPopupProvider::OnActionPerformed(const Tizen::Ui::Control& source, int actionId)
{
	AppLog("actionId: %d", actionId);

	switch(actionId)
	{
		case ID_BUTTON_PREV:
		{
			int index = GalleryAppWidgetState::GetIndex();
			index = (index == 0) ? 4 : index-1;
			GalleryAppWidgetState::SetIndex(index);
		}
		break;

		case ID_BUTTON_NEXT:
		{
			int index = GalleryAppWidgetState::GetIndex();
			index = (index == 4)? 0 : index+1;
			GalleryAppWidgetState::SetIndex(index);
		}
		break;
	}

	this->RequestUpdateToAppWidget();
}
