//
// Copyright (c) 2012 Samsung Electronics Co., Ltd.
//
// Licensed under the Flora License, Version 1.1 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://floralicense.org/license/
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an AS IS BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

#include <FBase.h>
#include <FApp.h>
#include <FSystem.h>
#include <FBaseRtThread.h>
#include <FGraphics.h>

#include "GalleryAppWidgetFrame.h"
#include "GalleryAppWidgetProvider.h"


using namespace Tizen::App;
using namespace Tizen::Base;
using namespace Tizen::Graphics;
using namespace Tizen::System;
using namespace Tizen::Ui::Controls;
using namespace Tizen::Shell;
using namespace Tizen::Base::Runtime;


GalleryAppWidgetProvider::GalleryAppWidgetProvider()
{
}

GalleryAppWidgetProvider::~GalleryAppWidgetProvider()
{
}

bool
GalleryAppWidgetProvider::OnAppWidgetProviderInitializing(float width, float height, const Tizen::Base::String& userInfo)
{
	AppLog("width:%f, height:%f userInfo:%ls", width, height, userInfo.GetPointer() );

	// TODO:
	// Initialize AppWidgetFrame and AppWidget provider specific data.
	// The AppWidget provider permanent data and context can be obtained from persistent storage.
	//
	// If this method is successful, return true; otherwise, return false.
	// If this method returns false, the AppWidget provider will be terminated.

	AppWidgetFrame* pFrame = new GalleryAppWidgetFrame();
	
	pFrame->Construct(FloatDimension(width, height));
	this->SetAppWidgetFrame(pFrame);
	pFrame->Show();

	return true;
}

void
GalleryAppWidgetProvider::OnAppWidgetProviderTerminating()
{
	AppLog("");
	// TODO:
	// Deallocate resources allocated by this AppWidget provider for termination.
	// But, you don't need to delete AppWidgetFrame instance, because AppWidgetProviderManager will delete it properly.
	// The AppWidget provider's permanent data and context can be saved to persistent storage such as appRegistry, DB, file.
}

void
GalleryAppWidgetProvider::OnAppWidgetProviderRemoved()
{
	AppLog("");
	// TODO:
	// The AppWidget provider's permanent data and context can be remove at here
}

bool
GalleryAppWidgetProvider::OnAppWidgetProviderUpdating(const Tizen::Base::String& argument)
{
	// TODO:
	// Add your code to update AppWidget here.
	//
	// If this method is successful, return true; otherwise, return false.
	// If this method returns false, the AppWidget provider will be terminated.

	AppLog("%ls", argument.GetPointer() );
	GalleryAppWidgetFrame* pFrame = static_cast<GalleryAppWidgetFrame*> (this->GetAppWidgetFrame());
	pFrame->OnAppWidgetUpdate();

	return true;
}

namespace
{
	const String REG_KEY_INDEX(L"APPWIDGET_INDEX");
}

int
GalleryAppWidgetState::GetIndex()
{
	AppRegistry *pAppRegistry = Application::GetInstance()->GetAppRegistry();
	AppAssertf(pAppRegistry, "Failed to get AppRegistry instance!");

	int value = 0;

	result r = pAppRegistry->Get(REG_KEY_INDEX, value);
	if ( r == E_KEY_NOT_FOUND)
	{
		AppLog("E_KEY_NOT_FOUND");

		pAppRegistry->Add(REG_KEY_INDEX, 0);
		pAppRegistry->Save();
		return 0;
	}

	AppLog("%d", value);

	return value;
}

void
GalleryAppWidgetState::SetIndex(int index)
{
	if( index < 0)
	{
		AppLog("Invalid index (%d)", index);
		index = 0;
	}

	AppRegistry *pAppRegistry = Application::GetInstance()->GetAppRegistry();
	pAppRegistry->Set(REG_KEY_INDEX, index);
	pAppRegistry->Save();
}
